#include "config.h"
#include <stdarg.h>
#include <stdio.h>
#include "log.h"
#include "recdb.h"

int bad = 0;

/* because recdb likes to log stuff.. */
void log(enum log_type lt, enum log_severity ls, char *format, ...)
{
    va_list va;
    (void)lt; (void)ls;
    va_start(va, format);
    vfprintf(stderr, format, va);
    va_end(va);
    bad = 1;
}

int check_record(const char *key, void *data, void *extra)
{
    struct record_data *rd = data;
    (void)extra;
    switch (rd->type) {
    case RECDB_INVALID:
	fprintf(stdout, "Invalid database record type for key %s\n", key);
	return 1;
    case RECDB_QSTRING:
    case RECDB_STRING_LIST:
	return 0;
    case RECDB_OBJECT:
	return dict_foreach(rd->d.object, check_record, NULL) ? 1 : 0;
    }
    return 0;
}

int main(int argc, char *argv[])
{
    dict_t db;

    if (argc < 2) {
	fprintf(stderr, "%s usage: %s <dbfile>\n", argv[0], argv[0]);
	return 1;
    }
    if (!(db = parse_database(argv[1]))) return 2;
    if (dict_foreach(db, check_record, 0)) return 3;
    if (!bad) fprintf(stdout, "Database checked okay.\n");
    return 0;
}
