/* proto.h - IRC protocol output
 * Copyright 2000-2002 srvx Development Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: proto.h,v 1.24.2.7.2.6 2002/04/09 04:10:15 entrope Exp $
 */

#if !defined(PROTO_H)
#define PROTO_H

#define COMBO_NUMERIC_LEN 5   /* 1/2, 1/3 or 2/3 digits for server/client parts */
#define MAXLEN		512   /* This is used all over as a maximum string lenth - keep it large */
#define MAXNUMPARAMS    200

#ifdef HAVE_NETINET_IN_H
#include <netinet/in.h>
#endif

struct server;
struct userNode;
struct chanNode;

/* connection manager state */

enum cState
{
    DISCONNECTED,
    AUTHENTICATING,
    BURSTING,
    CONNECTED
};

#define UPLINK_UNAVAILABLE	0x001

struct uplinkNode
{
    char		*name;

    char		*host;
    int			port;

    struct sockaddr_in 	*bind_addr;
    int 		bind_addr_len;

    char		*password;
    char		*their_password;

    enum cState		state;
    int			tries;
    int			max_tries;
    long		flags;

    struct uplinkNode	*prev;
    struct uplinkNode	*next;
};

struct cManagerNode
{
    struct uplinkNode	*uplinks;
    struct uplinkNode	*uplink;

    int			cycles;
    int			enabled;
};

/* replay silliness */
void replay_read_line(void);
void replay_event_loop(void);

/* connection maintenance */
void irc_server(struct server *srv);
void irc_user(struct userNode *user);
void irc_nick(struct userNode *user);
void irc_pass(const char *passwd);
void irc_introduce(const char *passwd);
void irc_burst(struct chanNode *chan);
void irc_eob(void);
void irc_eob_ack(void);
void irc_ping(const char *something);
void irc_pong(const char *data);
void irc_quit(struct userNode *user, const char *message);
void irc_squit(struct server *srv, const char *message);

/* messages */
void irc_privmsg(const char *from, const char *to, const char *message);
void irc_notice(const char *from, const char *to, const char *message);
void irc_wallchops(const char *from, const char *to, const char *message);

/* channel maintenance */
void irc_join(struct userNode *who, struct chanNode *what);
void irc_invite(struct userNode *from, struct userNode *who, struct chanNode *to);
int irc_make_chanmode(struct chanNode *chan, char *out);
void irc_mode(struct userNode *who, struct chanNode *target, const char *modes);
void irc_kick(struct userNode *who, struct userNode *target, struct chanNode *from, const char *msg);
void irc_part(struct userNode *who, struct chanNode *what, const char *reason);
void irc_topic(struct userNode *who, struct chanNode *what, const char *topic);
void irc_fetchtopic(struct userNode *from, const char *to);

/* network maintenance */
void irc_gline(const char *host, unsigned long duration, const char *message);
void irc_ungline(const char *mask);
void irc_error(const char *to, const char *message);
void irc_kill(struct userNode *from, struct userNode *target, const char *message);
void irc_raw(const char *what);
void irc_stats(struct userNode *from, struct server *target, char type);

/* numeric messages */
void irc_numeric(struct userNode *user, unsigned int num, const char *format, ...);

#endif /* !defined(PROTO_H) */
